Create objects/info/ directory in init-db.
authorJunio C Hamano <junkio@cox.net>
Sat, 20 Aug 2005 09:05:31 +0000 (02:05 -0700)
committerJunio C Hamano <junkio@cox.net>
Sat, 20 Aug 2005 17:59:28 +0000 (10:59 -0700)
Signed-off-by: Junio C Hamano <junkio@cox.net>
init-db.c
t/t0000-basic.sh

index 1fb3f7f..50b16b3 100644 (file)
--- a/init-db.c
+++ b/init-db.c
@@ -249,5 +249,7 @@ int main(int argc, char **argv)
        }
        strcpy(path+len, "/pack");
        safe_create_dir(path);
+       strcpy(path+len, "/info");
+       safe_create_dir(path);
        return 0;
 }
index 547488b..142b7bf 100755 (executable)
@@ -28,11 +28,12 @@ test_expect_success \
     '.git/objects should be empty after git-init-db in an empty repo.' \
     'cmp -s /dev/null should-be-empty' 
 
# also it should have 257 subdirectories.  258 is counting "objects"
 find .git/objects -type d -print >full-of-directories
 test_expect_success \
-    '.git/objects should have 257 subdirectories.' \
-    'test $(wc -l < full-of-directories) = 258'
+    '.git/objects should have 258 subdirectories.' \
+    'test $(wc -l < full-of-directories) = 259'
 
 ################################################################
 # Basics of the basics
@@ -28,11 +28,12 @@ test_expect_success \
     'cmp -s /dev/null should-be-empty' 
 
-# also it should have 257 subdirectories.  258 is counting "objects"
+# also it should have 258 subdirectories; 256 fan-out, pack, and info.
+# 259 is counting "objects" itself
 find .git/objects -type d -print >full-of-directories
 test_expect_success \